Pelican manager

[![Build Status](https://travis-ci.org/xiaojieluo/pelican-manager.svg?branch=master)](https://travis-ci.org/xiaojieluo/pelican-manager)
[![codecov](https://codecov.io/gh/xiaojieluo/pelican-manager/branch/master/graph/badge.svg)](https://codecov.io/gh/xiaojieluo/pelican-manager)
